@@ -114,7 +114,7 @@ class BertSTEMForTextClassification:
         return(encoded_dict)
 
 
-    def _train(self, inputs_train, inputs_val, num_train_epochs=3, learning_rate=1e-5, load_best_model_at_end=True):
+    def _train(self, inputs_train, inputs_val, num_train_epochs=3, learning_rate=1e-5, load_best_model_at_end=True, early_stopping_patience=5):
 
         dataset_train = CorpusDataset(inputs_train)
         dataset_val = CorpusDataset(inputs_val)
@@ -131,15 +131,21 @@ class BertSTEMForTextClassification:
                                                load_best_model_at_end=load_best_model_at_end,
                                                evaluation_strategy="epoch",
                                                save_strategy = "epoch")
-
+        
         early_stopping = transformers.EarlyStoppingCallback(early_stopping_patience=5)
+        
+        if load_best_model_at_end:
+            callbacks=[early_stopping]
+
+        else:
+            callbacks=[]
 
         trainer = transformers.Trainer(
                                model=self._model,                         # the instantiated Transformers model to be trained
                                args=training_args,                  # training arguments, defined above
                                train_dataset=dataset_train,               # training dataset
                                eval_dataset=dataset_val,                # evaluation dataset
-                               callbacks = [early_stopping])
+                               callbacks = callbacks)
 
         trainer.train()
 
